#include "UserBasedSample.h"
#include <iostream>

using namespace LicenseSpring;

void UserBasedSample::runOnline(bool deactivateAndRemove)
{
    auto license = m_licenseManager->getCurrentLicense();

    if (license == nullptr)
    {
        const std::string userId = "";
        const std::string userPassword = "";

        // In case multiple licenses of the same product are assigned to a single user, they are
        // differentiated by server-side license id
        auto userLicensesDataVec = m_licenseManager->getUserLicenses(userId, userPassword);
        for (const auto &userLicensesData : userLicensesDataVec)
            std::cout << "Server-side license id: " << userLicensesData->userLicense()->serverId()
                      << std::endl;

        // Server-side license id used only in case of multiple licenses assigned to same user
        uint64_t serverId = 0;

        // You can also call LicenseID::fromUser( userId, userPassword ) if serverId is 0
        auto licenseId = LicenseID::fromUser(userId, serverId, userPassword);

        if (userPassword.empty())
        {
            // After next call you will get invitation email where you can set up password for new
            // license user
            licenseId = m_licenseManager->getTrialLicense(userId);
            std::cout << "Trial license created for: " << licenseId.id() << std::endl;
        }

        license = m_licenseManager->activateLicense(licenseId);
        std::cout << "License activated successfully" << std::endl;
    }
    else
    {
        checkLicenseLocal(license);
        license = m_licenseManager->getCurrentLicense(); // update if local check initiated relink
    }

    if (license->isFloating())
        setupAutomaticLicenseUpdates(license);
    else
        updateAndCheckLicense(license);

    PrintLicense(license);

    printUpdateInfo();

    if (deactivateAndRemove)
        cleanUp(license);
}

void UserBasedSample::runOffline(bool deactivateAndRemove)
{
    auto license = m_licenseManager->getCurrentLicense();

    if (license == nullptr)
    {
        // You can provide here path to offline activation response file,
        // or use default desktop loaction and file name ls_activation.lic
        license = m_licenseManager->activateLicenseOffline();
        if (license == nullptr)
        {
            std::cout << "Offline activation error\n";

            const std::string userId = "someone@test.com";
            const std::string userPassword = "";

            createOfflineActivationRequest(LicenseID::fromUser(userId, userPassword));
            return;
        }
        else
            std::cout << "Offline activation succeeded\n";
    }

    checkLicenseLocal(license);
    license = m_licenseManager->getCurrentLicense(); // update if local check initiated relink

    updateOfflineLicense(license);

    PrintLicense(license);

    if (license->type() == LicenseTypeConsumption)
        license->updateConsumption();

    if (deactivateAndRemove)
        cleanUpLocal(license);
}
